Class: LogaltyCertificateIssuanceApiCerty::OcrResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- LogaltyCertificateIssuanceApiCerty::OcrResponse
- Defined in:
- lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb
Overview
OcrResponse Model.
Instance Attribute Summary collapse
-
#result ⇒ Array[OcrResultItem]
Structured data extracted from the identity document.
-
#validation ⇒ Array[OcrValidationItem]
Validation tests applied to the extracted data.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(result: SKIP, validation: SKIP, additional_properties: nil) ⇒ OcrResponse
constructor
A new instance of OcrResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(result: SKIP, validation: SKIP, additional_properties: nil) ⇒ OcrResponse
Returns a new instance of OcrResponse.
41 42 43 44 45 46 47 48 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 41 def initialize(result: SKIP, validation: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @result = result unless result == SKIP @validation = validation unless validation == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#result ⇒ Array[OcrResultItem]
Structured data extracted from the identity document.
14 15 16 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 14 def result @result end |
#validation ⇒ Array[OcrValidationItem]
Validation tests applied to the extracted data.
18 19 20 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 18 def validation @validation end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it result = nil unless hash['result'].nil? result = [] hash['result'].each do |structure| result << (OcrResultItem.from_hash(structure) if structure) end end result = SKIP unless hash.key?('result') # Parameter is an array, so we need to iterate through it validation = nil unless hash['validation'].nil? validation = [] hash['validation'].each do |structure| validation << (OcrValidationItem.from_hash(structure) if structure) end end validation = SKIP unless hash.key?('validation') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OcrResponse.new(result: result, validation: validation, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['result'] = 'result' @_hash['validation'] = 'validation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 29 def self.optionals %w[ result validation ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} result: #{@result.inspect}, validation: #{@validation.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_response.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} result: #{@result}, validation: #{@validation}, additional_properties:"\ " #{@additional_properties}>" end |