Class: LogaltyCertificateIssuanceApiCerty::OcrResultItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb

Overview

OcrResultItem Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, type: SKIP, value: SKIP, additional_properties: nil) ⇒ OcrResultItem

Returns a new instance of OcrResultItem.



47
48
49
50
51
52
53
54
55
56
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 47

def initialize(code: SKIP, type: SKIP, value: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @type = type unless type == SKIP
  @value = value unless value == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

OCR field identifier (e.g. ‘NAME`, `ID_NUMBER`, `EXPIRY`).

Returns:

  • (String)


14
15
16
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 14

def code
  @code
end

#typeString

Field category (e.g. ‘Normal`, `Validation`).

Returns:

  • (String)


18
19
20
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 18

def type
  @type
end

#valueString

Extracted field value.

Returns:

  • (String)


22
23
24
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 22

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP
  value = hash.key?('value') ? hash['value'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OcrResultItem.new(code: code,
                    type: type,
                    value: value,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['type'] = 'type'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 34

def self.optionals
  %w[
    code
    type
    value
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, type: #{@type.inspect}, value: #{@value.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/logalty_certificate_issuance_api_certy/models/ocr_result_item.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, type: #{@type}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end