Class: LogaltyCertificateIssuanceApiCerty::TokenResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/logalty_certificate_issuance_api_certy/models/token_response.rb

Overview

TokenResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token: SKIP, expires_in: SKIP, token_type: SKIP, additional_properties: nil) ⇒ TokenResponse

Returns a new instance of TokenResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 47

def initialize(access_token: SKIP, expires_in: SKIP, token_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token unless access_token == SKIP
  @expires_in = expires_in unless expires_in == SKIP
  @token_type = token_type unless token_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

Access token in JWT format.

Returns:

  • (String)


14
15
16
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 14

def access_token
  @access_token
end

#expires_inInteger

Token expiry time in seconds. Default is 3600 (1 hour).

Returns:

  • (Integer)


18
19
20
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 18

def expires_in
  @expires_in
end

#token_typeTokenType

Fixed value ‘Bearer`.

Returns:



22
23
24
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 22

def token_type
  @token_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : SKIP
  expires_in = hash.key?('expires_in') ? hash['expires_in'] : SKIP
  token_type = hash.key?('token_type') ? hash['token_type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenResponse.new(access_token: access_token,
                    expires_in: expires_in,
                    token_type: token_type,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['expires_in'] = 'expires_in'
  @_hash['token_type'] = 'token_type'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 34

def self.optionals
  %w[
    access_token
    expires_in
    token_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, expires_in: #{@expires_in.inspect},"\
  " token_type: #{@token_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/logalty_certificate_issuance_api_certy/models/token_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, expires_in: #{@expires_in}, token_type:"\
  " #{@token_type}, additional_properties: #{@additional_properties}>"
end