Class: LogaltyCertificateIssuanceApiCerty::TransactionResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb

Overview

TransactionResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, access_url: SKIP, cert_id: SKIP, additional_properties: nil) ⇒ TransactionResponse

Returns a new instance of TransactionResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 47

def initialize(code: SKIP, access_url: SKIP, cert_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @access_url = access_url unless access_url == SKIP
  @cert_id = cert_id unless cert_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_urlString

Synchronous URL to redirect the end-user to the issuing process.

Returns:

  • (String)


18
19
20
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 18

def access_url
  @access_url
end

#cert_idString

Unique identifier of the certificate in Logalty.

Returns:

  • (String)


22
23
24
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 22

def cert_id
  @cert_id
end

#codeUUID | String

Unique identifier of the transaction in Logalty (UUIDv4 format).

Returns:

  • (UUID | String)


14
15
16
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 14

def code
  @code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  access_url = hash.key?('accessUrl') ? hash['accessUrl'] : SKIP
  cert_id = hash.key?('certId') ? hash['certId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionResponse.new(code: code,
                          access_url: access_url,
                          cert_id: cert_id,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['access_url'] = 'accessUrl'
  @_hash['cert_id'] = 'certId'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 34

def self.optionals
  %w[
    code
    access_url
    cert_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, access_url: #{@access_url.inspect}, cert_id:"\
  " #{@cert_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/logalty_certificate_issuance_api_certy/models/transaction_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, access_url: #{@access_url}, cert_id: #{@cert_id},"\
  " additional_properties: #{@additional_properties}>"
end