Class: LogaltyCertificateIssuanceApiCerty::UnionTypeLookUp

Inherits:
Object
  • Object
show all
Includes:
CoreLibrary
Defined in:
lib/logalty_certificate_issuance_api_certy/utilities/union_type_lookup.rb

Overview

The ‘UnionTypeLookUp` class serves as a utility class for storing and managing type combinator templates. It acts as a container for the templates used in handling various oneof/anyof instances within the sdk.

Class Method Summary collapse

Class Method Details

.get(name) ⇒ Object

rubocop:enable Lint/RedundantCopDisableDirective, Style/HashSyntax, Layout/FirstArgumentIndentation



31
32
33
# File 'lib/logalty_certificate_issuance_api_certy/utilities/union_type_lookup.rb', line 31

def self.get(name)
  UnionTypeLookUp.union_types[name]
end

.union_typesObject

rubocop:disable Lint/RedundantCopDisableDirective, Style/HashSyntax, Layout/FirstArgumentIndentation



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
# File 'lib/logalty_certificate_issuance_api_certy/utilities/union_type_lookup.rb', line 13

def self.union_types
  {
    :UpdateRequest => OneOf.new(
      [
        LeafType.new(ResendRequest, UnionTypeContext.new(
          discriminator_value: 'resend',
          discriminator: 'operation'
        )),
        LeafType.new(CancelRequest, UnionTypeContext.new(
          discriminator_value: 'cancel',
          discriminator: 'operation'
        ))
      ]
    )
  }
end