Class: LogaltyCertificateIssuanceApiCerty::ErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- LogaltyCertificateIssuanceApiCerty::ErrorResponseException
- Defined in:
- lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb
Overview
ErrorResponse class.
Instance Attribute Summary collapse
-
#detail ⇒ String
Detailed explanation of the error and/or suggested correction.
-
#error ⇒ String
Identification code of the error type.
-
#message ⇒ String
Short, human-readable error message.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ ErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ ErrorResponseException
The constructor.
27 28 29 30 31 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#detail ⇒ String
Detailed explanation of the error and/or suggested correction.
22 23 24 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 22 def detail @detail end |
#error ⇒ String
Identification code of the error type.
14 15 16 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 14 def error @error end |
#message ⇒ String
Short, human-readable error message.
18 19 20 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 18 def @message end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} error: #{@error.inspect}, message: #{@message.inspect}, detail:"\ " #{@detail.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} error: #{@error}, message: #{@message}, detail: #{@detail}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/logalty_certificate_issuance_api_certy/exceptions/error_response_exception.rb', line 36 def unbox(hash) return nil unless hash @error = hash.key?('error') ? hash['error'] : SKIP @message = hash.key?('message') ? hash['message'] : SKIP @detail = hash.key?('detail') ? hash['detail'] : SKIP end |